summaryrefslogtreecommitdiff
path: root/telepathy-glib/automatic-proxy-factory.c
diff options
context:
space:
mode:
authorGuillaume Desmottes <guillaume.desmottes@collabora.co.uk>2011-05-25 14:04:33 +0200
committerGuillaume Desmottes <guillaume.desmottes@collabora.co.uk>2011-05-31 10:46:06 +0200
commitae747652aefbbc5169870af41ab6929244001a55 (patch)
tree9d66dd1edf8cfcbe4d57e65c5a5d1e5a0c8387c8 /telepathy-glib/automatic-proxy-factory.c
parentfee9c4dc6ba76fe55c9a75369fab46df41321e36 (diff)
downloadtelepathy-glib-ae747652aefbbc5169870af41ab6929244001a55.tar.gz
automatic-proxy-factory: prepare TP_CHANNEL_FEATURE_PASSWORD
Diffstat (limited to 'telepathy-glib/automatic-proxy-factory.c')
-rw-r--r--telepathy-glib/automatic-proxy-factory.c6
1 files changed, 5 insertions, 1 deletions
diff --git a/telepathy-glib/automatic-proxy-factory.c b/telepathy-glib/automatic-proxy-factory.c
index 56b428d09..36c53cb2a 100644
--- a/telepathy-glib/automatic-proxy-factory.c
+++ b/telepathy-glib/automatic-proxy-factory.c
@@ -53,7 +53,8 @@
*
* <itemizedlist>
* <listitem>
* <para>%TP_CHANNEL_FEATURE_CORE and %TP_CHANNEL_FEATURE_GROUP for all
* type of channels.</para>
* </listitem>
* <listitem>
@@ -185,6 +186,9 @@ tp_automatic_proxy_factory_dup_channel_features_impl (TpChannel *channel)
feature = TP_CHANNEL_FEATURE_GROUP;
g_array_append_val (features, feature);
+ feature = TP_CHANNEL_FEATURE_PASSWORD;
+ g_array_append_val (features, feature);
+
if (TP_IS_TEXT_CHANNEL (channel))
{
feature = TP_TEXT_CHANNEL_FEATURE_INCOMING_MESSAGES;
@@ -53,7 +53,8 @@
* <itemizedlist>
* <listitem>
- * <para>%TP_CHANNEL_FEATURE_CORE and %TP_CHANNEL_FEATURE_GROUP for all
+ * <para>%TP_CHANNEL_FEATURE_CORE, %TP_CHANNEL_FEATURE_GROUP
+ * and %TP_CHANNEL_FEATURE_PASSWORD for all
* type of channels.</para>
* </listitem>